@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -63,7 +63,7 @@ sub generate {
     print "NEXT: $next_chord\n" if $self->verbose && $next_chord;
 
     my $scale = $self->scale->($chord);
-    my $next_scale = defined $next_chord ? $self->scale->($next_chord) : 'major';
+    my $next_scale = defined $next_chord ? $self->scale->($next_chord) : '';
 
     # Parse the chord
     my $chord_note;
@@ -78,7 +78,6 @@ sub generate {
     if ($next_chord && $next_chord =~ /^([A-G][#b]?).*$/) {
         $next_chord_note = $1;
     }
-warn __PACKAGE__,' L',__LINE__,' ',,"$next_chord_note\n" if $next_chord_note;
 
     my $cn = Music::Chord::Note->new;
 
@@ -202,7 +201,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
